{% extends 'timeseer.html' %}

{% from 'help.html' import help_menu with context %}

{% block csp_style %}
'self' 'unsafe-inline'
{% endblock %}

{% block menu %}
{{ help_menu('Compliance report') }}
{% endblock %}

{% block main %}
<div class="ts-section py-3 my-3">
    <h2 class="h4">Compliance report</h2>
</div>

<div class="my-3 py-3">
    {% include 'compliance/license-report.html'%}
</div>
{% endblock %}
