{% extends 'timeseer.html' %}
{% from 'macros.html' import edit_multivariate_metadata, menu_back %}

{% block menu %}
{{ menu_back(url_for('.template_metadata', templatename=template.name, sourcename=source_name)) }}
{% endblock %}

{% block main %}
<div class="ts-section py-3 my-3">
    <h2 class="h4">Edit metadata</h2>
     <p class="h6 text-break">{{ template.name }}</p>
</div>

<div class="pt-3 my-3">
    <form method="POST">
        <input type="hidden" name="csrf_token" value="{{ csrf_token() }}">
        {{ edit_multivariate_metadata(metadata, process_types) }}
        <button type="submit" class="btn btn-primary me-2">Save</button>
        <a href="{{ url_for('.template_metadata', templatename=template.name, sourcename=source_name) }}"
            class="btn btn-secondary">
            Cancel
        </a>
    </form>
</div>
{% endblock %}
