{% extends 'timeseer.html' %}

{% from 'macros.html' import bootstrap_icon, menu_back %}

{% block menu %}
{{ menu_back(url_for('sources.display_configuration', sourcename=source_name)) }}
{% endblock %}

{% block main %}
<div class="ts-section py-3 my-3">
    <h2 class="h4">Remove evaluation</h2>
    <p class="h6 text-break">{{ source_name }}</p>
</div>

<div class="pt-3 my-3">
    <p>Evaluated at {{ flow_evaluation_group.date|ts_datetime }}.</p>
    <form method="POST">
        <input type="hidden" name="csrf_token" value="{{ csrf_token() }}">
        <input type="hidden" name="flowevaluationgroupid" value="{{ flow_evaluation_group.db_id }}">
        <input type="hidden" name="sourcename" value="{{ source_name }}">
        <div class="btn-toolbar">
            <button type="submit" class="btn btn-primary me-2">Yes</button>
            <a class="btn btn-secondary"
                href="{{ url_for('sources.display_configuration', sourcename=source_name) }}"
                role="button">
                Cancel
            </a>
        </div>
    </form>
</div>
{% endblock %}
