{% extends 'tags-layout.html' %}

{% block menu %}
{{ prepare_menu('Statistics') }}
{% endblock %}

{% block tags_title %}
<h2 class="h4">Statistics</h2>
{% endblock %}

{% block tags_content %}
{% if statistics %}
{% include 'fragments/statistics-table.html' %}
{% else %}
{% if analysis_state is not none and analysis_state.is_defined() %}
<div class="alert alert-info">
    No statistics available.
</div>
{% endif %}
{% endif %}
{% endblock tags_content %}
