{% from 'macros.html' import menu, visualize_series_name %}

{% macro data_service_series_menu(active) %}
{{
    menu(
        (bootstrap_icon('arrow-left', 'h5 fw-bolder m-0', 24), back_url),
        [
            ('Metadata', url_for('data_services.display_metadata', seriesid=series.series_id, viewevaluationid=view_evaluation.db_id)),
            ('Statistics', url_for('data_services.show_statistics', seriesid=series.series_id, viewevaluationid=view_evaluation.db_id)),
            ('Event frames', url_for('data_services.show_event_frames', seriesid=series.series_id, viewevaluationid=view_evaluation.db_id)),
            ('Chart', url_for('data_services.chart', seriesid=series.series_id, viewevaluationid=view_evaluation.db_id)),
            ('Exports', url_for('data_services.series_exports', seriesid=series.series_id, viewevaluationid=view_evaluation.db_id)),
            ('History', url_for('data_services.history', seriesid=series.series_id, viewevaluationid=view_evaluation.db_id)),
        ],
        active,
    )
}}
{% endmacro %}
